@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.4 
+/* GrandPerspective, Version 3.4.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -203,16 +203,25 @@ NSString  *DisplaySettingsChangedEvent = @"displaySettingsChanged";
   UniqueTagsTransformer  *tagMaker = UniqueTagsTransformer.defaultUniqueTagsTransformer;
 
   [colorMappingPopUp removeAllItems];
-  [tagMaker addLocalisedNames: colorMappings.allKeys
-                      toPopUp: colorMappingPopUp
-                       select: nil // displaySettings.colorMappingKey
-                        table: @"Names"];
+  [tagMaker addLocalisedNamesFor: colorMappings.allKeys
+                         toPopUp: colorMappingPopUp
+                          select: nil // displaySettings.colorMappingKey
+                           table: @"Names"];
 
   [colorPalettePopUp removeAllItems];
-  [tagMaker addLocalisedNames: colorPalettes.allKeys
-                      toPopUp: colorPalettePopUp
-                       select: nil // displaySettings.colorPaletteKey
-                        table: @"Names"];
+
+  // Use palette size as main sort criterion for palettes (with the localized name as tie-breaker)
+  NSArray  *sortedKeys = [colorPalettes allKeysSortedByPaletteSize:
+                           ^NSComparisonResult(id _Nonnull key1, id _Nonnull key2) {
+    NSString  *s1 = [NSBundle.mainBundle localizedStringForKey: key1 value: nil table: @"Names"];
+    NSString  *s2 = [NSBundle.mainBundle localizedStringForKey: key2 value: nil table: @"Names"];
+
+    return [s1 compare: s2];
+  }];
+  [tagMaker addSortedLocalisedNamesFor: sortedKeys
+                               toPopUp: colorPalettePopUp
+                                select: nil
+                                 table: @"Names"];
 
   maskPopUpControl = [[FilterPopUpControl alloc] initWithPopUpButton: maskPopUp
                                                     filterRepository: filterRepository];
