@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.4 
+/* GrandPerspective, Version 3.4.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -62,7 +62,10 @@ extern NSString  *ViewWillCloseEvent;
   
   // The part of the (absolute) path that is outside the visible tree.
   NSString  *invisiblePathName;
-  
+
+  // Status message that is temporarily shown in the status bar
+  NSString  *statusMessage;
+
   // The size of the view when it is not zoomed.
   NSSize  unzoomedViewSize;
 }
