@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.4 
+/* GrandPerspective, Version 3.4.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -86,16 +86,16 @@ NSString  *SelectedFilterUpdated = @"selectedFilterUpdated";
              object: repositoryFiltersByName];
 
     [popUpButton removeAllItems];
-    [tagMaker addLocalisedNames: filterRepository.filtersByName.allKeys
-                        toPopUp: popUpButton
-                         select: nil
-                          table: @"Names"];
+    [tagMaker addLocalisedNamesFor: filterRepository.filtersByName.allKeys
+                           toPopUp: popUpButton
+                            select: nil
+                             table: @"Names"];
 
     if (addNoneOption) {
-      [tagMaker addLocalisedName: NoneFilter
-                         toPopUp: popUpButton
-                          select: NO
-                           table: @"Names"];
+      [tagMaker addLocalisedNameFor: NoneFilter
+                            toPopUp: popUpButton
+                             select: NO
+                              table: @"Names"];
     }
   }
   return self;
@@ -144,7 +144,7 @@ NSString  *SelectedFilterUpdated = @"selectedFilterUpdated";
 - (void) filterAddedToRepository:(NSNotification *)notification {
   NSString  *name = notification.userInfo[@"key"];
   
-  [tagMaker addLocalisedName: name toPopUp: popUpButton select: NO table: @"Names"];
+  [tagMaker addLocalisedNameFor: name toPopUp: popUpButton select: NO table: @"Names"];
 }
 
 - (void) filterRemovedFromRepository:(NSNotification *)notification {
@@ -179,7 +179,7 @@ NSString  *SelectedFilterUpdated = @"selectedFilterUpdated";
   BOOL  wasSelected = popUpButton.indexOfSelectedItem == index;
   
   [popUpButton removeItemAtIndex: index];
-  [tagMaker addLocalisedName: newName toPopUp: popUpButton select: wasSelected table: @"Names"];
+  [tagMaker addLocalisedNameFor: newName toPopUp: popUpButton select: wasSelected table: @"Names"];
 
   if (wasSelected) {
     [notificationCenter postNotificationName: SelectedFilterRenamed object: self];
