@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.4 
+/* GrandPerspective, Version 3.4.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -247,10 +247,10 @@ static BOOL appHasDeletePermission;
 
   // Initialise the pop-up with its (localized) content
   [popUp removeAllItems];
-  [tagMaker addLocalisedNames: names
-                      toPopUp: popUp
-                       select: [userDefaults stringForKey: key]
-                        table: @"Names"];
+  [tagMaker addLocalisedNamesFor: names
+                         toPopUp: popUp
+                          select: [userDefaults stringForKey: key]
+                           table: @"Names"];
 }
 
 - (void) setupDefaultDisplayFocusPopUp {
@@ -286,7 +286,7 @@ static BOOL appHasDeletePermission;
            withTitle: title
              toPopUp: popUp
              atIndex: index
-              select: [title isEqualToString: prefValue]];
+              select: [UnlimitedDisplayFocusValue isEqualToString: prefValue]];
 }
 
 - (void) setPopUp: (NSPopUpButton *)popUp toValue:(NSString *)value {
