@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.4 
+/* GrandPerspective, Version 3.4.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -21,7 +21,7 @@
 
 @interface ColorListCollection : NSObject {
 
-  NSMutableDictionary  *colorListDictionary;
+  NSMutableDictionary<NSString*, NSColorList*>  *colorListDictionary;
 }
 
 @property (class, nonatomic, readonly) ColorListCollection *defaultColorListCollection;
@@ -29,7 +29,9 @@
 - (void) addColorList:(NSColorList *)colorList key:(NSString *)key;
 - (void) removeColorListForKey:(NSString *)key;
 
-@property (nonatomic, readonly, copy) NSArray *allKeys;
+@property (nonatomic, readonly, copy) NSArray<NSString *> *allKeys;
+
+- (NSArray<NSString *> *)allKeysSortedByPaletteSize:(NSComparator)tieBreaker;
 
 - (NSColorList *)colorListForKey:(NSString *)key;
 
