@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.4 
+/* GrandPerspective, Version 3.4.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -23,7 +23,7 @@
 @implementation UniqueTagsTransformer
 
 + (Class) transformedValueClass {
-  return [NSNumber class];
+  return NSNumber.class;
 }
 
 + (BOOL) allowsReverseTransformation {
@@ -89,22 +89,22 @@
 }
 
 
-- (void) addLocalisedNames:(NSArray *)names
-                   toPopUp:(NSPopUpButton *)popUp
-                    select:(NSString *)selectName
-                     table:(NSString *)tableName {
+- (void) addLocalisedNamesFor:(NSArray *)names
+                      toPopUp:(NSPopUpButton *)popUp
+                       select:(NSString *)selectName
+                        table:(NSString *)tableName {
   for (NSString *name in [names objectEnumerator]) {
-    [self addLocalisedName: name
-                   toPopUp: popUp
-                    select: [name isEqualToString: selectName]
-                     table: tableName];
+    [self addLocalisedNameFor: name
+                      toPopUp: popUp
+                       select: [name isEqualToString: selectName]
+                        table: tableName];
   }
 }
 
-- (void) addLocalisedName:(NSString *)name 
-                  toPopUp:(NSPopUpButton *)popUp
-                   select:(BOOL) select
-                    table:(NSString *)tableName {
+- (void) addLocalisedNameFor:(NSString *)name
+                     toPopUp:(NSPopUpButton *)popUp
+                      select:(BOOL) select
+                       table:(NSString *)tableName {
   NSString  *localizedName = [NSBundle.mainBundle localizedStringForKey: name
                                                                   value: nil
                                                                   table: tableName];
@@ -127,6 +127,24 @@
           select: select];
 }
 
+- (void) addSortedLocalisedNamesFor:(NSArray *)names
+                            toPopUp:(NSPopUpButton *)popUp
+                             select:(NSString *)selectName
+                              table:(NSString *)tableName {
+  int  index = (int)popUp.numberOfItems;
+
+  for (NSString *name in [names objectEnumerator]) {
+    NSString  *localizedName = [NSBundle.mainBundle localizedStringForKey: name
+                                                                    value: nil
+                                                                    table: tableName];
+    [self addValue: name
+         withTitle: localizedName
+           toPopUp: popUp
+           atIndex: index++
+            select: [name isEqualToString: selectName]];
+  }
+}
+
 - (void) addValue:(NSObject *)value
         withTitle:(NSString *)title
           toPopUp:(NSPopUpButton *)popUp
