@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.4 
+/* GrandPerspective, Version 3.4.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -29,6 +29,9 @@ extern NSString  *ColorPaletteChangedEvent;
  */
 extern NSString  *ColorMappingChangedEvent;
 
+/* Event fired when the display focus changed.
+ */
+extern NSString  *DisplayFocusChangedEvent;
 
 @class AsynchronousTaskManager;
 @class TreeLayoutBuilder;
