@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.4 
+/* GrandPerspective, Version 3.4.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -56,6 +56,7 @@ static const float ZOOM_ANIMATION_MAXLEN_THRESHOLD = 0.80;
 
 NSString  *ColorPaletteChangedEvent = @"colorPaletteChanged";
 NSString  *ColorMappingChangedEvent = @"colorMappingChanged";
+NSString  *DisplayFocusChangedEvent = @"displayFocusChanged";
 
 CGFloat rectArea(NSRect rect) {
   return rect.size.width * rect.size.height;
@@ -95,6 +96,7 @@ CGFloat ramp(CGFloat x, CGFloat minX, CGFloat maxX) {
 
 - (void) postColorPaletteChanged;
 - (void) postColorMappingChanged;
+- (void) postDisplayFocusChanged;
 
 - (void) selectedItemChanged:(NSNotification *)notification;
 - (void) visibleTreeChanged:(NSNotification *)notification;
@@ -168,6 +170,8 @@ CGFloat ramp(CGFloat x, CGFloat minX, CGFloat maxX) {
   DrawTaskExecutor  *drawTaskExecutor =
     [[[DrawTaskExecutor alloc] initWithTreeContext: treeContext] autorelease];
   drawTaskManager = [[AsynchronousTaskManager alloc] initWithTaskExecutor: drawTaskExecutor];
+
+  pathModelView.showPackageContents = self.treeDrawerSettings.showPackageContents;
   pathModelView.displayDepth = self.treeDrawerSettings.displayDepth;
 
   OverlayDrawTaskExecutor  *overlayDrawTaskExecutor =
@@ -484,6 +488,8 @@ CGFloat ramp(CGFloat x, CGFloat minX, CGFloat maxX) {
 
   // Ensure the change is always visible
   self.displayDepth = MIN(self.maxDrawDepth, self.treeDrawerSettings.displayDepth) - 1;
+
+  [self postDisplayFocusChanged];
 }
 
 - (void) moveDisplayFocusDown:(id)sender {
@@ -496,10 +502,14 @@ CGFloat ramp(CGFloat x, CGFloat minX, CGFloat maxX) {
   }
 
   self.displayDepth = newDepth;
+
+  [self postDisplayFocusChanged];
 }
 
 - (void) resetDisplayFocus:(id)sender {
   self.displayDepth = TreeDrawerSettings.defaultDisplayDepth;
+
+  [self postDisplayFocusChanged];
 }
 
 
@@ -1084,6 +1094,11 @@ CGFloat ramp(CGFloat x, CGFloat minX, CGFloat maxX) {
                                                     object: self];
 }
 
+- (void) postDisplayFocusChanged {
+  [NSNotificationCenter.defaultCenter postNotificationName: DisplayFocusChangedEvent
+                                                    object: self];
+}
+
 /* Called when selection changes in path
  */
 - (void) selectedItemChanged:(NSNotification *)notification {
